@@ -2,13 +2,12 @@ from t2wml.mapping.datamart_edges import clean_id
 import yaml
 import os
 import warnings
-from t2wml.utils.debug_logging import basic_debug
 from pathlib import Path
 from shutil import copyfile
 from t2wml.spreadsheets.sheet import SpreadsheetFile
 from t2wml.utils.t2wml_exceptions import FileWithThatNameInProject, FileNotPresentInProject, InvalidProjectDirectory
 from t2wml.settings import DEFAULT_SPARQL_ENDPOINT
-
+from t2wml.utils.debug_logging import basic_debug
 
 
 
@@ -50,6 +49,7 @@ class Project:
         if not self.entity_file.exists():
             with open(self.entity_file, 'w') as f:
                 f.write("{}")
+            
     
     @property
     def entity_file(self):
@@ -86,7 +86,7 @@ class Project:
                         index+=1
                         file_name=Path(file_path).stem+"_"+str(index)+Path(file_path).suffix
                         dst=os.path.join(self.directory, file_name)
-                    pass #print("renamed to: ", file_name)
+                    #print("renamed to: ", file_name)
                 else:
                     raise FileWithThatNameInProject(str(dst))
             try:
@@ -94,6 +94,7 @@ class Project:
                 file_path=file_name
             except Exception as e:
                 raise ValueError("Failed to copy provided file to project directory: "+str(e))
+            
         return Path(file_path).as_posix() #save forward slash strings, windows anyway knows how to handle them 
     
     def add_data_file(self, file_path, copy_from_elsewhere=False, overwrite=False, rename=False):
@@ -169,7 +170,6 @@ class Project:
             self.entity_files= [file_path]+self.entity_files
         return file_path
     
-    @basic_debug
     def add_annotation_file(self, annotation_path, data_path, sheet_name, copy_from_elsewhere=False, overwrite=False, rename=False):
         annotation_path=self._add_file(annotation_path, copy_from_elsewhere, overwrite, rename)
         data_path=self._normalize_path(data_path)
@@ -186,6 +186,7 @@ class Project:
             self.annotations[data_path]={sheet_name:dict(val_arr=[annotation_path], selected=annotation_path)}
         return annotation_path
 
+    @basic_debug
     def _normalize_path(self, file_path):
         root=Path(self.directory)
         full_path=Path(file_path)
@@ -214,6 +215,7 @@ class Project:
                     return True
         return False
     
+    @basic_debug
     def delete_file_from_project(self, file_path, delete_from_fs=False):
         if not self.path_in_files(file_path):
             raise ValueError("The file you are trying to delete does not exist in project")
@@ -256,8 +258,9 @@ class Project:
                 del_path=self.get_full_path(del_val)
                 os.remove(del_path)
             except Exception as e:
-                pass #print(e)
+                print(e)
                 
+    @basic_debug
     def rename_file_in_project(self, old_name, new_name, rename_in_fs=False):
         old_name=self._normalize_path(old_name)
         new_name=self._normalize_path(new_name)
@@ -306,7 +309,7 @@ class Project:
             os.makedirs(full_folder_path, exist_ok=True)
             old_file_path=self.get_full_path(old_name)
             os.rename(old_file_path, new_file_path)
-    
+        
     @basic_debug
     def save(self):
         output_dict=dict(self.__dict__)
