@@ -1,20 +1,16 @@
 import json
-from t2wml.utils.debug_logging import basic_debug, with_args_debug, t2wml_log
 import pandas as pd
 from pandas import DataFrame
 from collections import defaultdict
 from t2wml.utils.t2wml_exceptions import ItemNotFoundException
 from t2wml.utils.bindings import bindings
+from t2wml.utils.debug_logging import basic_debug
 
 
 class ItemTable:
     def __init__(self, lookup_table={}):
         self.lookup_table = defaultdict(dict, lookup_table)
-    
-    def __repr__(self):
-        return "<Item Table>"
 
-    @with_args_debug
     def lookup_func(self, context, file, sheet, column, row, value):
         lookup = self.lookup_table.get(context)
         if not lookup:
@@ -26,6 +22,7 @@ class ItemTable:
         row = int(row)
         tuples = [
             (file, sheet, column, row, value),
+            (file, sheet, '', '', value),
             ('', '', column, row, value),
             ('', '', column, row, ''),
             ('', '', column, '', value),
@@ -39,8 +36,10 @@ class ItemTable:
             item = lookup.get(str(tup))
             if item:
                 return item
+
         raise ValueError("Not found")
 
+    @basic_debug
     def get_item(self, column:int, row:int, context:str='', sheet=None, value=None):
         if not sheet:
             sheet = bindings.excel_sheet
@@ -55,6 +54,7 @@ class ItemTable:
             return None  # currently this is what the rest of the API expects. could change later
         #   raise ItemNotFoundException("Item for cell "+to_excel(column, row)+"("+value+")"+"with context "+context+" not found")
 
+    @basic_debug
     def get_item_by_string(self, value: str, context:str=''):
         lookup = self.lookup_table.get(context)
         if not lookup:
@@ -76,35 +76,22 @@ class ItemTable:
                 return item, context, value
         return None, None, None
 
-    @with_args_debug
+    @basic_debug
     def update_table_from_dataframe(self, df: DataFrame):
-        try:
-            t2wml_log.debug("replace na with empty string")
             df = df.fillna('')
-            t2wml_log.debug("replace regex in dataframe")
             df = df.replace(r'^\s+$', '', regex=True)
             overwritten = {}
-            
-            t2wml_log.debug("gathering all tuples")
-            tuples = list(df.itertuples())
-            t2wml_log.debug(f"gathered {len(tuples)} tuples")
-
-            t2wml_log.debug('Iterating over gathered tupled')
-            for (idx, entry) in enumerate(tuples):
-                t2wml_log.debug(f"entry index {idx}")
-                t2wml_log.debug("fetching fields from entry:")
+            for entry in df.itertuples():
                 column = entry.column
                 row = entry.row
                 value = str(entry.value)
                 context = entry.context
                 item = entry.item
-                t2wml_log.debug(f"column {column} row {row} value {value} context {context} item {item}")
                 try:
                     file = entry.file
                     sheet= entry.sheet
                 except:
                     file=sheet="" #backwards compatible for now
-                t2wml_log.debug(f" adding fields for: file {file} sheet {sheet}")
 
                 if not item:
                     raise ValueError("Item definition missing")
@@ -114,33 +101,17 @@ class ItemTable:
                         "at least one of column, row, or value must be defined")
 
                 if column != "":
-                    t2wml_log.debug("convert column to int")
                     column = int(column)
                 if row != "":
-                    t2wml_log.debug("convert row to int")
                     row = int(row)
-                t2wml_log.debug("create tuple key")
                 key = str((file, sheet, column, row, value))
-                t2wml_log.debug(f"key: {str(key)}")
-                t2wml_log.debug("check if already exists in lookup table")
                 if self.lookup_table[context].get(key):
-                    t2wml_log.debug("it does already exist")
                     overwritten[key] = self.lookup_table[context][key]
-                else:
-                    t2wml_log.debug("it doesn't already exist")
-                t2wml_log.debug("add/overwrite in lookup table")
                 self.lookup_table[context][key] = item
-                t2wml_log.debug(f"Done with iteration {idx}")
 
-            t2wml_log.debug('Exited loop')
             if len(overwritten):
-                t2wml_log.debug("print count for overwritten")
-                ##print("Wikifier update overwrote existing values: "+str(overwritten))
-            t2wml_log.debug('returning from function')
+                print(f"Wikifier update overwrote {len(overwritten)} existing values")
             return overwritten
-        except Exception as e:
-            #print(e)
-            raise e
 
 
 class Wikifier:
@@ -149,21 +120,11 @@ class Wikifier:
         self._data_frames = []
         self._item_table = ItemTable()
 
-    def print_data(self):
-        """prints a little summary of the contents of the wikifier
-        """
-        print("The wikifier contains {} wiki files, and a total of {} dataframes".format(
-            len(self.wiki_files), len(self._data_frames)))
-        if len(self.wiki_files):
-            print("The files are:")
-            for filename in self.wiki_files:
-                print(filename)
-
     @property
     def item_table(self):
         return self._item_table
 
-    @with_args_debug
+    @basic_debug
     def add_file(self, file_path: str):
         """add a wikifier file to the wikifier. loads the file and adds it to the item table.
         file must be a csv file, and must contain the columns 'row', 'column', 'value', 'context', 'item'
@@ -188,7 +149,7 @@ class Wikifier:
         self._data_frames.append(df)
         return overwritten
 
-    @with_args_debug
+    @basic_debug
     def add_dataframe(self, df: DataFrame):
         """Add a wikifier dataframe to the Wikifier item table
 
